package com.xlht.xlhtproject.domain;


import com.fasterxml.jackson.annotation.JsonFormat;
import lombok.AllArgsConstructor;
import lombok.Builder;
import lombok.Data;
import lombok.NoArgsConstructor;

import java.math.BigDecimal;
import java.util.Date;

/**
 * 智能投药参数设置对象
 * 
 * @author slibra
 * @date 2024-09-09
 */
@Data
@Builder
@NoArgsConstructor
@AllArgsConstructor
public class TXlhtMedicineParam
{
    private static final Long serialVersionUID = 1L;

    /** 主键 */
    private Long id;

    /** 1池自动方式（0自动 1人工投放） */
    private Integer typeOne;

    /** 2池自动方式（0自动 1人工投放） */
    private Integer typeTwo;

    /** 进水流量类型1池（0手动 1仪表） */
    private Integer jsLlTypeOne;

    /** 进水流量1号池 */
    private BigDecimal jsLlOne;

    /** 进水流量类型2池（0手动 1仪表） */
    private Integer jsLlTypeTwo;

    /** 进水流量2号池 */
    private BigDecimal jsLlTwo;

    /** 进水cod类型1池（0手动 1仪表 2化验） */
    private Integer jsCodTypeOne;

    /** 进水cod1号池 */
    private BigDecimal jsCodOne;

    /** 进水cod类型2池（0手动 1仪表 2化验） */
    private Integer jsCodTypeTwo;

    /** 进水cod二号池 */
    private BigDecimal jsCodTwo;

    /** 好氧池硝酸盐类型1池（0手动 1化验 2预测） */
    private Integer hycXsyTypeOne;

    /** 好氧池硝酸盐1号池 */
    private BigDecimal hycXsyOne;

    /** 好氧池硝酸盐类型2池（0手动 1化验 2预测） */
    private Integer hycXsyTypeTwo;

    /** 好氧池硝酸盐2号池 */
    private BigDecimal hycXsyTwo;

    /** 缺氧池硝酸盐类型1池（0手动 1化验） */
    private Integer qycYxyTypeOne;

    /** 缺氧池硝酸盐1号池 */
    private BigDecimal qycYxyOne;

    /** 缺氧池硝酸盐类型2池（0手动 1化验） */
    private Integer qycYxyTypeTwo;

    /** 缺氧池硝酸盐2号池 */
    private BigDecimal qycYxyTwo;

    /** 缺氧池氨氮类型1池（0手动 1化验） */
    private Integer qycAdTypeOne;

    /** 缺氧池氨氮1号池 */
    private BigDecimal qycAdOne;

    /** 缺氧池氨氮类型2池（0手动 1化验） */
    private Integer qycAdTypeTwo;

    /** 缺氧池氨氮2号池 */
    private BigDecimal qycAdTwo;

    /** 进水总氮类型1池（0手动 1仪表） */
    private Integer jsTnTypeOne;

    /** 进水总氮1号池 */
    private BigDecimal jsTnOne;

    /** 进水总氮类型2池（0手动 1仪表） */
    private Integer jsTnTypeTwo;

    /** 进水总氮2号池 */
    private BigDecimal jsTnTwo;

    /** 后台反馈设定1池 */
    private BigDecimal htfksdOne;

    /** 后台反馈设定2池 */
    private BigDecimal htfksdTwo;

    /** 基准系数1池 */
    private BigDecimal jzxsOne;

    /** 基准系数2池 */
    private BigDecimal jzxsTwo;

    /** 修正系数1池 */
    private BigDecimal xzxsOne;

    /** 修正系数2池 */
    private BigDecimal xzxsTwo;

    /** 控制系数1池 */
    private BigDecimal kzxsOne;

    /** 控制系数2池 */
    private BigDecimal kzxsTwo;

    /** 水量分配系数1池 */
    private BigDecimal slfpxsOne;

    /** 水量分配系数2池 */
    private BigDecimal slfpxsTwo;

    /** 碳源当量1池 */
    private BigDecimal tydlOne;

    /** 碳源当量2池 */
    private BigDecimal tydlTwo;

    /** 转换系数1池 */
    private BigDecimal zhxsOne;

    /** 转换系数2池 */
    private BigDecimal zhxsTwo;

    /** 稀释配属1池 */
    private BigDecimal sxpsOne;

    /** 稀释配属2池 */
    private BigDecimal sxpsTwo;

    /** 药剂密度1池 */
    private BigDecimal yymdOne;

    /** 药剂密度2池 */
    private BigDecimal yymdTwo;

    /** 最小启动流量1池 */
    private BigDecimal zxqdllOne;

    /** 最小启动流量2池 */
    private BigDecimal zxqdllTwo;

    /** 加药量1池 */
    private BigDecimal medicineAmountOne;

    /** 加药量2池 */
    private BigDecimal medicineAmountTwo;

    /** 碳氮比1池 */
    private BigDecimal tdbOne;

    /** 碳氮比2池 */
    private BigDecimal tdbTwo;

    /** 乐观锁 */
    private Integer revision;

    /** 删除标志（0代表存在 2代表删除） */
    private Integer delFlag;


    //额外查询的字段
    //碳源投加瞬时流量(一池)
    private BigDecimal tytjTransientLLOne;

    //碳源投加瞬时流量(二池)
    private BigDecimal tytjTransientLLTwo;




    /** 创建者 */
    private String createBy;

    /** 创建时间 */
    @JsonFormat(pattern = "yyyy-MM-dd HH:mm:ss")
    private Date createTime;

    /** 更新者 */
    private String updateBy;

    /** 更新时间 */
    @JsonFormat(pattern = "yyyy-MM-dd HH:mm:ss")
    private Date updateTime;

    /** 备注 */
    private String remark;

    //2024年10月08日11:37:38  新增的返回字段

    //1池（北池）远程就地状态 1远程  0就地
    private Integer oneRemoteStatus;
    //2池（南池）远程就地状态 1远程  0就地
    private Integer twoRemoteStatus;

    //请求参数

    /**  开始时间 */
    private String timeBegin;

    /** 截止时间 */
    private String timeEnd;

    /** 当前记录起始索引 */
    private Integer pageNum = 1;

    /** 每页显示记录数 */
    private Integer pageSize = 10;
}
